==> apache-seatunnel-incubating-2.2.0-beta-src.tar.gz: apache-seatunnel-incubating-2.2.0-beta-src/seatunnel-connectors-v2/connector-file/connector-file-base/src/main/java/org/apache/seatunnel/connectors/seatunnel/file/config/Constant.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.file.config;

public class Constant {
    public static final String SEATUNNEL = "seatunnel";
    public static final String NON_PARTITION = "NON_PARTITION";
    public static final String TRANSACTION_ID_SPLIT = "_";
    public static final String TRANSACTION_EXPRESSION = "transactionId";

    public static final String SAVE_MODE = "save_mode";
    public static final String COMPRESS_CODEC = "compress_codec";

    public static final String PATH = "path";
    public static final String FIELD_DELIMITER = "field_delimiter";
    public static final String ROW_DELIMITER = "row_delimiter";
    public static final String PARTITION_BY = "partition_by";
    public static final String PARTITION_DIR_EXPRESSION = "partition_dir_expression";
    public static final String IS_PARTITION_FIELD_WRITE_IN_FILE = "is_partition_field_write_in_file";
    public static final String TMP_PATH = "tmp_path";
    public static final String FILE_NAME_EXPRESSION = "file_name_expression";
    public static final String FILE_FORMAT = "file_format";
    public static final String SINK_COLUMNS = "sink_columns";
    public static final String FILENAME_TIME_FORMAT = "filename_time_format";
    public static final String IS_ENABLE_TRANSACTION = "is_enable_transaction";
}

==> apache-seatunnel-incubating-2.3.0-beta-src.tar.gz: apache-seatunnel-incubating-2.3.0-beta-src/seatunnel-connectors-v2/connector-file/connector-file-base/src/main/java/org/apache/seatunnel/connectors/seatunnel/file/config/Constant.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.file.config;

public class Constant {
    public static final String SEATUNNEL = "seatunnel";
    public static final String NON_PARTITION = "NON_PARTITION";
    public static final String TRANSACTION_ID_SPLIT = "_";
    public static final String TRANSACTION_EXPRESSION = "transactionId";
    public static final String SAVE_MODE = "save_mode";
    public static final String COMPRESS_CODEC = "compress_codec";
    public static final String DATE_FORMAT = "date_format";
    public static final String DATETIME_FORMAT = "datetime_format";
    public static final String TIME_FORMAT = "time_format";
    public static final String PATH = "path";
    public static final String FIELD_DELIMITER = "field_delimiter";
    public static final String ROW_DELIMITER = "row_delimiter";
    public static final String PARTITION_BY = "partition_by";
    public static final String PARTITION_DIR_EXPRESSION = "partition_dir_expression";
    public static final String IS_PARTITION_FIELD_WRITE_IN_FILE = "is_partition_field_write_in_file";
    public static final String TMP_PATH = "tmp_path";
    public static final String FILE_NAME_EXPRESSION = "file_name_expression";
    public static final String FILE_FORMAT = "file_format";
    public static final String SINK_COLUMNS = "sink_columns";
    public static final String FILENAME_TIME_FORMAT = "filename_time_format";
    public static final String IS_ENABLE_TRANSACTION = "is_enable_transaction";
}
